package MT::Plugin::HatenaBookmarkWidget;

use strict;
use LWP::Simple;

use base qw( MT::Plugin );
our $VERSION = '0.2.090819';

my $plugin = MT::Plugin::HatenaBookmarkWidget->new({
    id          => 'HatenaBookmarkWidget',
    name        => 'Hatena Bookmark Widget',
    key         => 'hatena-bookmark-widget',
    description => "This dashboard widget shows hatena bookmark for each blog. This version is modified by Shinichi Nozawa and released 09/02/10.",
    version     => $VERSION,
    author_name => 'Akira Sawada',
	autor_link  => 'http://blog.aklaswad.com/2007/000170.html',
	plugin_link => 'http://nozawashinichi.sakura.ne.jp/usingmt/2009/02/hatenabookmarkwidget-modified.html',
	
});
MT->add_plugin($plugin);

sub init_registry { 
    my $plugin = shift;
    $plugin->registry({
        applications => {
            'cms' => {
                widgets => {
                    'HatenaBookmark' => {
                        label => 'HatenaBookmark',
                        template => 'tmpl/widget.tmpl',
                        handler => \&_widget_handler,
                        set => 'sidebar',
                        singular => 1,
                        condition => sub {
                            my ($page, $scope) = @_;
                            return $page eq 'dashboard' && $scope !~ /system/;
                        },
                    },
                },
            },
        },
    });
}

sub _widget_handler {
    my $app = shift;
    my ($tmpl, $param) = @_;
    my $blog = $app->blog;
    die 'not in blog context' unless $blog;
    my $blog_url = $blog->site_url;
    $param->{blog_url} = $blog_url;
    my $feed_url = 'http://b.hatena.ne.jp/bookmarklist.rss?url=' . $blog_url;

	#my $ua = MT->new_ua;
    my $content = get($feed_url);


    require XML::Simple;
    my $parser = new XML::Simple(forcearray => 1);
    my $data = $parser->XMLin($content);

    my @bookmarks;
	
	if(ref($data->{item}) ne 'ARRAY'){
		$app->log("HatenaBookMarkWidget: No items?");
		return 1; 
	}
	
	for(@{$data->{item}}){
		my $title = $_->{title}[0];
		#utf8::encode($title);
		MT::I18N::encode_text( $title, 'utf-8', undef );
		#$app->log($title);
		
		my @tags;
		#$app->log(Dumper($_->{'dc:subject'}));
		for my $t ($_->{'dc:subject'}){
			my $array = ref($t) ne 'ARRAY'? [] : $t;
			for(@$array){
				MT::I18N::encode_text($_, 'utf-8', undef);
				push @tags, {tag => $_};
			}
		}
		
		#$app->log( $_->{description}[0]);
		my $description = ref $_->{description}[0] eq '' ? $_->{description}[0] : '';
		MT::I18N::encode_text($description, 'utf-8', undef);
		#$app->log($description);
		
		push @bookmarks, {
			link => $_->{link},
			title => $title,
			description => $description,
			date => $_->{'dc:date'},
			creator     => $_->{'dc:creator'},
			bm_link     => $_->{'rdf:about'},
			tags        => \@tags, 
			image_src   => 'http://www.hatena.ne.jp/users/'.substr( $_->{'dc:creator'}[0], 0, 2).'/'.$_->{'dc:creator'}[0].'/profile_s.gif',
		};
		
	}

		$param->{hatenabookmark} = \@bookmarks;

}

1;

